WineBox - Wine Cellar Management
Author: Joe Drumgoole
Description: AI-powered wine cellar management. Scan wine labels with your phone, track your cellar inventory, discover tasting notes, and explore over 100,000 wines from around the world.

## Welcome to WineBox

Sign in to manage your wine cellar

Email
Password
Stay logged in on this machine
Forgot password? | Create account

## Create Account

Join WineBox to manage your wine cellar

Email
Password
At least 8 characters
Confirm Password
Already have an account? Sign in

## Reset Password

Enter your email to receive a password reset link

Email
← Back to sign in

## Set New Password

Enter your new password

New Password
At least 8 characters
Confirm New Password

## Verifying Email...

Please wait while we verify your email address.

Continue to sign in

## Dashboard

-
Bottles
-
Wines
-
Tracked
-
Met

### Wine Types

### Price Range

### Top Countries

### Top Grape Varieties

### Vintages

### Recent Activity

## Add Wine

Scan a label to record a wine you've encountered

### Label Images

Front Label (Required)
Tap to take photo or select image
Back Label (Optional)
Tap to take photo or select image

### Wine Details

Leave fields blank to use OCR-detected values

Wine Name
Winery
Vintage
Grape Variety
Region
Country
Wine Type
More Details
Sub-Region
Appellation
Alcohol %
Classification
Price Tier
Producer Type
Drink Window Start
Drink Window End
Custom Fields
Notes

### Raw Label Text

+
Front Label OCR:

Back Label OCR:

## My Cellar

No Image
Sancerre
Domaine de la Villaudière - 2000
Country France
Region Sancerre
Grape: Sauvignon BlancABV: 14%_demo: true
More...
No Image
Napa Valley Cabernet Sauvignon
Chateau Montelena - 1981
Country United States
Region Napa Valley
Grape: Cabernet SauvignonABV: 13.9%_demo: true
More...
No Image
Chianti
Ruffino - 2014
Country Italy
Region Chianti
Grape: SangioveseABV: 12.5%_demo: true
More...
No Image
Lamùri Nero d'Avola Regaleali
Tasca d'Almerita - 2007
Country Italy
Region Terre Siciliane
Grape: Nero d'AvolaABV: 13.5%_demo: true
More...
No Image
PassioneSentimento Rosso
Pasqua Vigneti e Cantine - 2009
Country Italy
Region Veneto
Grape: CorvinaABV: 14%_demo: true
More...
No Image
Brut Prestige
Mumm Napa
Country United States
Region Rutherford
Grape: Pinot MeunierABV: 12.5%_demo: true
More...
No Image
Le G de Guiraud Bordeaux Blanc Sec
Château Guiraud - 1988
Country France
Region Bordeaux
Grape: Sauvignon BlancABV: 13.5%_demo: true
More...
No Image
Pauillac (Grand Cru Classé)
Château Batailley - 2012
Country France
Region Pauillac
Grape: Petit VerdotABV: 12.5%_demo: true
More...
No Image
Antiguas Reservas Cabernet Sauvignon
Cousiño-Macul - 1988
Country Chile
Region Maipo Valley
Grape: Cabernet SauvignonABV: 14%_demo: true
More...
No Image
Essential Red
Bogle - 1961
Country United States
Region California
Grape: Petite SirahABV: 13.5%_demo: true
More...
No Image
Bordeaux (Élevé en Fûts de Chêne)
Baron de Lestac - 1986
Country France
Region Bordeaux
Grape: Cabernet SauvignonABV: 13%_demo: true
More...
No Image
Zinfandel
Barefoot - 2012
Country United States
Region Lodi
Grape: ZinfandelABV: 13.5%_demo: true
More...
No Image
Sauvignon Blanc
Kim Crawford - 1987
Country New Zealand
Region Marlborough
Grape: Sauvignon BlancABV: 13%_demo: true
More...
No Image
Cabernet-Cabernet
Catena Zapata - 2013
Country Argentina
Region Mendoza
Grape: Cabernet SauvignonABV: 14%_demo: true
More...
No Image
Sauvignon Blanc
Babich - 2016
Country New Zealand
Region Marlborough
Grape: Sauvignon BlancABV: 13%_demo: true
More...
No Image
Chardonnay
Cloudy Bay - 2000
Country New Zealand
Region Marlborough
Grape: ChardonnayABV: 13.2%_demo: true
More...
No Image
Old Vine Zinfandel
Bogle - 1993
Country United States
Region California
Grape: ZinfandelABV: 14.5%_demo: true
More...
No Image
Is Argiolas Vermentino di Sardegna
Argiolas - 2005
Country Italy
Region Sardegna
Grape: VermentinoABV: 14.5%_demo: true
More...
No Image
Classic Shiraz-Cabernet
Jacob's Creek - 1998
Country Australia
Region South Eastern Australia
Grape: Syrah/ShirazABV: 13.9%_demo: true
More...
No Image
Oro Tempranillo Valdepeñas
Pata Negra - 1969
Country Spain
Region Valdepeñas
Grape: TempranilloABV: 13%_demo: true
More...
No Image
Bonarda
El Enemigo - 2001
Country Argentina
Region Mendoza
Grape: BonardaABV: 13.9%_demo: true
More...
No Image
Blanc de Blancs Brut
Schramsberg - 1994
Country United States
Region Napa Valley
Grape: ChardonnayABV: 12.9%_demo: true
More...
No Image
Montepulciano d'Abruzzo (Il Vino dal Tralcetto Riserva)
Cantina Zaccagnini - 2012
Country Italy
Region Abruzzo
Grape: MontepulcianoABV: 13%_demo: true
More...
No Image
Malbec (I)
Pulenta Estate - 1990
Country Argentina
Region Mendoza
Grape: MalbecABV: 14.5%_demo: true
More...
No Image
Sauternes (Grand Cru Classé)
Château d'Arche - 1971
Country France
Region Sauternes
Grape: SémillonABV: 13.5%_demo: true
More...
No Image
Pauillac (Grand Cru Classé)
Château Clerc Milon - 2014
Country France
Region Pauillac
Grape: Cabernet SauvignonABV: 14.5%_demo: true
More...
No Image
Domaine Sainte Claire Chablis
Jean-Marc Brocard - 1975
Country France
Region Chablis
Grape: ChardonnayABV: 12.5%_demo: true
More...
No Image
Mosel Riesling Feinherb
Dr. Willkomm - 2006
Country Germany
Region Mosel
Grape: RieslingABV: 11.5%_demo: true
More...
No Image
Rosé
Villa Francioni - 2007
Country Brazil
Region Santa Catarina
Grape: Syrah/ShirazABV: 13.2%_demo: true
More...
No Image
Dry Riesling
Chateau Ste. Michelle - 2014
Country United States
Region Columbia Valley
Grape: RieslingABV: 13%_demo: true
More...
No Image
Pinot Noir Santa Barbara County
Au Bon Climat - 1968
Country United States
Region Santa Barbara County
Grape: Pinot NoirABV: 13.5%_demo: true
More...
No Image
Petite Sirah
Bogle - 1970
Country United States
Region California
Grape: Syrah/ShirazABV: 13.5%_demo: true
More...
No Image
The Velvet Devil Merlot
Charles Smith - 1995
Country United States
Region Washington
Grape: MerlotABV: 13.5%_demo: true
More...
No Image
Reserva Rioja (Finca Ygay)
Marqués de Murrieta - 1964
Country Spain
Region Rioja
Grape: TempranilloABV: 14%_demo: true
More...
No Image
Cabernet Sauvignon
Alamos - 2013
Country Argentina
Region Mendoza
Grape: Cabernet SauvignonABV: 13.5%_demo: true
More...
No Image
Alandra Tinto
Esporão - 2009
Country Portugal
Region Alentejano
Grape: Syrah/ShirazABV: 13%_demo: true
More...
No Image
Villa Antinori Chianti Classico Riserva
Antinori - 1982
Country Italy
Region Chianti Classico
Grape: SangioveseABV: 13.5%_demo: true
More...
No Image
Allo Alvarinho-Loureiro
Soalheiro - 2021
Country Portugal
Region Monção e Melgaço
Grape: AlvarinhoABV: 11%_demo: true
More...
No Image
Tramari Rosé di Primitivo
San Marzano - 2004
Country Italy
Region Puglia
Grape: PrimitivoABV: 12.5%_demo: true
More...
No Image
Saint Louis de Provence Rosé
Estandon - 1987
Country France
Region Coteaux Varois en Provence
Grape: Syrah/ShirazABV: 12.5%_demo: true
More...
No Image
Cava Reserva Heredad Brut
Segura Viudas - 2021
Country Spain
Region Cava
Grape: ParelladaABV: 12%_demo: true
More...
No Image
Bicicleta Reserva Unoaked Chardonnay
Cono Sur - 2021
Country Chile
Region Santiago
Grape: ChardonnayABV: 13.5%_demo: true
More...
No Image
Alma Mora Malbec
Bodega Finca Las Moras - 1986
Country Argentina
Region San Juan
Grape: MalbecABV: 13%_demo: true
More...
No Image
Rioja Reserva
Luis Cañas - 2005
Country Spain
Region Rioja
Grape: TempranilloABV: 14%_demo: true
More...
No Image
Impérial Rosé Brut Champagne
Moët & Chandon
Country France
Region Champagne
Grape: Pinot NoirABV: 12%_demo: true
More...
No Image
Seleção Cabernet Sauvignon-Tempranillo Rosé
Miolo - 2019
Country Brazil
Region Campanha Gaúcha
Grape: Cabernet SauvignonABV: 12%_demo: true
More...
No Image
Cabernet Sauvignon
Joseph Phelps - 1979
Country United States
Region Napa Valley
Grape: Cabernet SauvignonABV: 14.5%_demo: true
More...
No Image
Chardonnay
Robert Mondavi - 2008
Country United States
Region Napa Valley
Grape: ChardonnayABV: 13.5%_demo: true
More...
No Image
R.D Extra Brut Champagne (Récemment Dégorgé)
Bollinger - 1976
Country France
Region Champagne
Grape: Pinot NoirABV: 12%_demo: true
More...
No Image
Fincas Malbec
Alfredo Roca - 1981
Country Argentina
Region San Rafael
Grape: MalbecABV: 13.3%_demo: true
More...
No Image
Vin de Constance (Natural Sweet)
Klein Constantia - 2015
Country South Africa
Region Constantia
Grape: Muscat of FrontignanABV: 14%_demo: true
More...
No Image
Cabernet Sauvignon
Faust - 2005
Country United States
Region Napa Valley
Grape: Cabernet SauvignonABV: 14.2%_demo: true
More...
No Image
The Winemaster's Pinotage
Nederburg - 1995
Country South Africa
Region Coastal Region
Grape: PinotageABV: 14.2%_demo: true
More...
No Image
Arienzo Rioja Crianza
Marqués de Riscal - 2004
Country Spain
Region Rioja
Grape: TempranilloABV: 14%_demo: true
More...
No Image
Gran Enemigo
El Enemigo - 2010
Country Argentina
Region Mendoza
Grape: MalbecABV: 13.9%_demo: true
More...
No Image
Riesling Trocken
Robert Weil - 1997
Country Germany
Region Rheingau
Grape: RieslingABV: 12%_demo: true
More...
No Image
Sauvignon Blanc
Peter Yealands - 2012
Country New Zealand
Region Marlborough
Grape: Sauvignon BlancABV: 12.5%_demo: true
More...
No Image
Verdejo
José Pariente - 2018
Country Spain
Region Rueda
Grape: VerdejoABV: 13.5%_demo: true
More...
No Image
Sauternes Barsac (Premier Grand Cru Classé)
Château Coutet - 1971
Country France
Region Barsac
Grape: Sauvignon BlancABV: 14%_demo: true
More...
No Image
Clos de la Coulée de Serrant
Nicolas Joly - 1967
Country France
Region Saumur
Grape: Chenin BlancABV: 15%_demo: true
More...
No Image
Zinfandel
1000 Stories - 2009
Country United States
Region California
Grape: ZinfandelABV: 15.2%_demo: true
More...
No Image
Rosé
Maison Saint Aix - 2019
Country France
Region Coteaux d'Aix-en-Provence
Grape: Syrah/ShirazABV: 13%_demo: true
More...
No Image
Art Series Chardonnay
Leeuwin Estate - 2002
Country Australia
Region Margaret River
Grape: ChardonnayABV: 13.5%_demo: true
More...
No Image
Cabernet Sauvignon
Liberty School - 1975
Country United States
Region Paso Robles
Grape: Cabernet SauvignonABV: 13.5%_demo: true
More...
No Image
Sauternes (Premier Grand Cru Classé)
Château Rabaud-Promis - 1992
Country France
Region Sauternes
Grape: SémillonABV: 13.5%_demo: true
More...
No Image
Torrontes
Alamos - 2001
Country Argentina
Region Salta
Grape: TorrontésABV: 13.5%_demo: true
More...
No Image
Alambre Moscatel de Setúbal
José Maria da Fonseca - 1981
Country Portugal
Region Setúbal
Grape: Muscat/MoscatoABV: 17.4%_demo: true
More...
No Image
Montepulciano d'Abruzzo
Masciarelli - 2020
Country Italy
Region Abruzzo
Grape: MontepulcianoABV: 13%_demo: true
More...
No Image
Barolo Serralunga d'Alba
Fontanafredda - 1979
Country Italy
Region Barolo
Grape: NebbioloABV: 13.5%_demo: true
More...
No Image
Cocodrilo Red Blend
Viña Cobos - 2013
Country Argentina
Region Mendoza
Grape: Cabernet SauvignonABV: 14.5%_demo: true
More...
No Image
Brunello di Montalcino
Caparzo - 1988
Country Italy
Region Brunello di Montalcino
Grape: SangioveseABV: 14%_demo: true
More...
No Image
EA Tinto
Cartuxa - 2013
Country Portugal
Region Evora
Grape: CastelãoABV: 12.5%_demo: true
More...
No Image
Malbec
Latitud 33 - 1999
Country Argentina
Region Mendoza
Grape: MalbecABV: 14%_demo: true
More...
No Image
Silk Soft Red Blend
Ménage à Trois - 1996
Country United States
Region California
Grape: Pinot NoirABV: 13.7%_demo: true
More...
No Image
Rossj-Bass Langhe
Gaja - 2001
Country Italy
Region Langhe
Grape: ChardonnayABV: 13.5%_demo: true
More...
No Image
Haulashore Sauvignon Blanc
Seifried Estate - 2021
Country New Zealand
Region Nelson
Grape: Sauvignon BlancABV: 12.5%_demo: true
More...
No Image
Rioja Reserva
Remelluri - 1979
Country Spain
Region Rioja
Grape: TempranilloABV: 13.7%_demo: true
More...
No Image
Rioja Reserva
Beronia - 1966
Country Spain
Region Rioja
Grape: GracianoABV: 14%_demo: true
More...
No Image
Barolo (Tradizione)
Marchesi di Barolo - 1955
Country Italy
Region Barolo
Grape: NebbioloABV: 14%_demo: true
More...
No Image
Joseph Gewürztraminer
J. Hofstätter - 2002
Country Italy
Region Südtirol-Alto Adige
Grape: GewürztraminerABV: 14.5%_demo: true
More...
No Image
Winemaker's Selection Branco
Portada - 2001
Country Portugal
Region Lisboa
Grape: ChardonnayABV: 12%_demo: true
More...
No Image
Prestige Collection Brut Prosecco Treviso
Mionetto
Country Italy
Region Veneto
Grape: Glera/ProseccoABV: 11%_demo: true
More...
No Image
Ice Impérial (Demi-Sec) Champagne
Moët & Chandon
Country France
Region Champagne
Grape: ChardonnayABV: 12%_demo: true
More...
No Image
Brunello di Montalcino
Biondi-Santi
Country Italy
Region Brunello di Montalcino
Grape: SangioveseABV: 10%_demo: true
More...
No Image
Bordeaux
Clarendelle - 1983
Country France
Region Bordeaux
Grape: Cabernet SauvignonABV: 13.5%_demo: true
More...
No Image
Classic Provence Rosé
Mirabeau - 2005
Country France
Region Côtes de Provence
Grape: Syrah/ShirazABV: 13.5%_demo: true
More...
No Image
Côtes de Gascogne Premières Grives
Domaine du Tariquet - 2008
Country France
Region Gers
Grape: Gros MansengABV: 11.5%_demo: true
More...
No Image
Torcolato
Maculan - 2012
Country Italy
Region Breganze
Grape: VespolinaABV: 13.5%_demo: true
More...
No Image
Ripassa Valpolicella Ripasso Superiore
Zenato - 2021
Country Italy
Region Veneto
Grape: CorvinaABV: 14%_demo: true
More...
No Image
Brunello di Montalcino
Tenuta CastelGiocondo - 1974
Country Italy
Region Brunello di Montalcino
Grape: SangioveseABV: 14.5%_demo: true
More...
No Image
Brunello di Montalcino
Banfi - 1984
Country Italy
Region Brunello di Montalcino
Grape: SangioveseABV: 13.8%_demo: true
More...
No Image
Red Blend
Conundrum - 2019
Country United States
Region Napa Valley
Grape: Cabernet SauvignonABV: 14%_demo: true
More...
No Image
Sauvignon Blanc
Matua - 2011
Country New Zealand
Region Marlborough
Grape: Sauvignon BlancABV: 13%_demo: true
More...
No Image
Riesling Alsace Réserve
Gustave Lorentz - 1951
Country France
Region Alsace
Grape: RieslingABV: 12.5%_demo: true
More...
No Image
Barolo
Prunotto - 2014
Country Italy
Region Barolo
Grape: NebbioloABV: 13.5%_demo: true
More...
No Image
Cuvée Elegance Clairette de Die Tradition
Union des Jeunes Vignerons Récoltants - 2018
Country France
Region Rhone Valley
Grape: Grenache BlancABV: 12.5%_demo: true
More...
No Image
Zinfandel
Carnivor - 2021
Country United States
Region California
Grape: ZinfandelABV: 14.5%_demo: true
More...
No Image
ARTEMIS Cabernet Sauvignon
Stag's Leap Wine Cellars - 1991
Country United States
Region Napa Valley
Grape: Cabernet SauvignonABV: 14.5%_demo: true
More...
No Image
(B) Old Vine Zinfandel Lodi
Brazin - 2008
Country United States
Region California
Grape: ZinfandelABV: 14.5%_demo: true
More...
No Image
Moscato
Barefoot - 1950
Country United States
Region Napa Valley
Grape: Muscat/Moscato BiancoABV: 9%_demo: true
More...

## Wines I've Met

Wines you've encountered in shops, restaurants, and tastings

## Add Wine to Your Cellar

Choose how you'd like to add a wine

### Scan a Label

Take a photo to auto-detect wine details

### Enter Details Manually

Type in the wine details and quantity

### From a Wine I've Met

Add a wine you previously recorded

### Import from File

Upload a CSV or Excel spreadsheet

### Scan Label

Front Label (Required)
Tap to take photo or select image
Back Label (Optional)
Tap to take photo or select image
Scanning label...

### Wine Details

Detected from label — edit as needed

Wine Name
Winery
Vintage
Grape Variety
Region
Country
Wine Type
Quantity (Bottles)

### Enter Wine Details

Wine Name
Winery
Vintage
Grape Variety
Region
Country
Wine Type
Quantity (Bottles)

### Select a Wine You've Met

####

How many bottles?

### Upload Spreadsheet

Drag and drop your file here, or

Browse Files

Supported formats: CSV, Excel (.xlsx). Max 10,000 rows.

We'll help you match your columns in the next step. Nothing is imported until you confirm.

Advanced import options...
Always show column mapping step Use AI to automatically match columns (takes a few extra seconds)

### Match Your Columns

Tell us what each column in your spreadsheet contains. We've made our best guess — just check and adjust anything that looks wrong.

### Your data (first 5 rows)

No quantity column matched — each wine will be added as 1 bottle.

### Adding wines to your cellar...

0 / 0 rows 0%
0 wines created 0 rows skipped
Skip automatic detail lookup (faster, but missing details like region or grape won't be filled in)

### Import Complete

### We already have this data

### Add More Details

These columns from your file weren't imported. Map them to wine fields to add the information to your wines.

### Just Added

### Your New Wines

### Your Cellar at a Glance

×

## Transaction History

### Activity Timeline

### Removal Reasons

### Activity Summary

## Search Wines

Search
Advanced Filters
Vintage
Grape Variety
Winery
Region
Country
Wine Type
Price Tier
In Stock Only

## Wine Reference

Search over 100,000 wines from around the world

Search
Wine Type
Country
Results
Price Range (USD)
to
Page 1 of 1
×

## Settings

### Change Password

Current Password
New Password
Confirm New Password

### Danger Zone

Permanently delete your entire wine collection, including all wines, transactions, label images, and import history. This action cannot be undone.

×

### Remove Wine

What happened to this wine?

Quantity
Tasting notes (optional)
Sale price ($)
Who did you give it to?
What happened? (optional)
×

### Confirm Wine Details

Review and edit the details before saving

Wine Name
Winery
Vintage
Grape Variety
Region
Sub-Region
Appellation
Country
Alcohol %
Wine Type
Classification
Price Tier
Producer Type
Custom Fields
Notes
Show Raw Label Text +
Front Label:

Back Label:

How many bottles?
×

### Delete Entire Collection

This will permanently delete all your wines, transactions, label images, and import history. This action cannot be undone.

Type DELETE to confirm:
×

### Delete Wine

Are you sure you want to delete this wine and all its history? This action cannot be undone.

×

### Skipped Rows